SA_DEFAULT_KEY = 'sa_main'

DEFAULT_KEY = SA_DEFAULT_KEY  # synonym
